vortex\_properties module
========================================================

.. automodule:: IMTreatment.vortex_properties.vortex_properties
    :members:
    :undoc-members:
    :show-inheritance:
